@@ -39,10 +39,13 @@ def get_app_template_dir(app_name):
 
 
 if django.VERSION >= (1, 9):
-    def get_template_path(template_dir, template_name,
-                          loader=None):  # pylint: disable=unused-argument
+    def get_template_path(template_dir, template_name, loader=None):
         """Return Origin object with template file path"""
-        return Origin(name=join(template_dir, template_name))
+        return Origin(
+            name=join(template_dir, template_name),
+            template_name=template_name,
+            loader=loader,
+        )
 else:
     def get_template_path(template_dir, template_name,
                           loader=None):  # pylint: disable=unused-argument
@@ -56,6 +59,7 @@ class Loader(FilesystemLoader):
     """
     is_usable = True
 
+    # pylint: disable=arguments-differ,unused-argument
     def get_template_sources(self, template_name, template_dirs=None):
         """
         Return the absolute paths to "template_name" in the specified app
